@@ -1,7 +1,8 @@
 import functools
 import textwrap
 import uuid
-from typing import List, Optional
+import warnings
+from typing import Any, List, Optional, Tuple
 
 import typer
 
@@ -39,13 +40,13 @@ from globus_automate_client.cli.rich_helpers import (
     RunListDisplayFields,
     RunLogDisplayFields,
 )
-from globus_automate_client.cli.rich_rendering import live_content
 from globus_automate_client.client_helpers import create_flows_client
 from globus_automate_client.flows_client import (
     RUN_STATUS_SCOPE,
     FlowValidationError,
     validate_flow_definition,
 )
+from globus_automate_client.helpers import validate_aliases
 
 app = typer.Typer(short_help="Manage Globus Automate Flows")
 
@@ -63,6 +64,19 @@ def dedent(text: str) -> str:
     return textwrap.dedent(text).strip()
 
 
+def handle_aliases(canonical_item: Tuple[str, Any], *aliases: Tuple[str, Any]) -> Any:
+    """Validate aliases, and handle exceptions in a CLI context."""
+
+    try:
+        return validate_aliases(canonical_item, *aliases)
+    except ValueError as error:
+        typer.secho(error.args[0], err=True)
+        raise typer.Abort()
+    except DeprecationWarning as warning:
+        typer.secho(warning.args[0], err=True)
+        return warning.args[2]
+
+
 @app.callback()
 def flows():
     """
@@ -79,8 +93,9 @@ def flow_deploy(
     definition: str = typer.Option(
         ...,
         help=(
-            "JSON or YAML representation of the Flow to deploy. May be provided as a filename "
-            "or a raw string representing a JSON object or YAML definition."
+            "JSON or YAML representation of the Flow to deploy. "
+            "May be provided as a filename or a raw string "
+            "representing a JSON object or YAML definition."
         ),
         prompt=True,
         callback=input_validator,
@@ -118,7 +133,8 @@ def flow_deploy(
         callback=custom_principal_validator({"public"}),
         hidden=False,
     ),
-    # viewer and visible_to are aliases for the full flow_viewer
+    # viewer and visible_to are aliases for flow_viewer.
+    # Both are deprecated.
     viewer: List[str] = typer.Option(
         None,
         callback=custom_principal_validator({"public"}),
@@ -135,12 +151,13 @@ def flow_deploy(
             "A principal which may run an instance of the deployed Flow. "
             + _principal_description
             + "The special value of "
-            "'all_authenticated_users' may be used to indicate that any authenticated user "
-            "can invoke this flow. [repeatable]"
+            "'all_authenticated_users' may be used to indicate that "
+            "any authenticated user can invoke this flow. [repeatable]"
         ),
         callback=custom_principal_validator({"all_authenticated_users"}),
     ),
-    # starter and runnable_by are aliases for the full flow_starter
+    # starter and runnable_by are aliases for flow_starter.
+    # Both are deprecated.
     starter: List[str] = typer.Option(
         None,
         callback=custom_principal_validator({"all_authenticated_users"}),
@@ -160,7 +177,8 @@ def flow_deploy(
         ),
         callback=principal_validator,
     ),
-    # administrator and administered_by are aliases for the full flow_administrator
+    # administrator and administered_by are aliases for flow_administrator.
+    # Both are deprecated.
     administrator: List[str] = typer.Option(
         None, callback=principal_validator, hidden=True
     ),
@@ -169,7 +187,7 @@ def flow_deploy(
     ),
     subscription_id: Optional[str] = typer.Option(
         None,
-        help="The Id of the Globus Subscription which will be used to make this flow managed.",
+        help="The ID of the Globus Subscription which will manage the Flow.",
     ),
     validate: bool = typer.Option(
         True,
@@ -192,6 +210,23 @@ def flow_deploy(
     """
     Deploy a new Flow.
     """
+
+    flow_viewer = handle_aliases(
+        ("--flow-viewer", flow_viewer),
+        ("--viewer", viewer or None),
+        ("--visible-to", visible_to or None),
+    )
+    flow_starter = handle_aliases(
+        ("--flow-starter", flow_starter),
+        ("--starter", starter or None),
+        ("--runnable-by", runnable_by or None),
+    )
+    flow_administrator = handle_aliases(
+        ("--flow-administrator", flow_administrator),
+        ("--administrator", administrator or None),
+        ("--administered-by", administered_by or None),
+    )
+
     fc = create_flows_client(CLIENT_ID, flows_endpoint)
     flow_dict = process_input(definition)
     input_schema_dict = process_input(input_schema)
@@ -206,15 +241,17 @@ def flow_deploy(
         subtitle,
         description,
         keywords,
-        visible_to,
-        runnable_by,
-        administered_by,
+        flow_viewer,
+        flow_starter,
+        flow_administrator,
         subscription_id,
         input_schema_dict,
         validate_definition=validate,
         dry_run=dry_run,
     )
-    RequestRunner(method, format=output_format, verbose=verbose).run_and_render()
+    with warnings.catch_warnings():
+        warnings.simplefilter("ignore", category=DeprecationWarning)
+        RequestRunner(method, format=output_format, verbose=verbose).run_and_render()
 
 
 @app.command("get")
@@ -239,8 +276,8 @@ def flow_update(
     definition: str = typer.Option(
         None,
         help=(
-            "JSON or YAML representation of the Flow to update. May be provided as a filename "
-            "or a raw string."
+            "JSON or YAML representation of the Flow to update. "
+            "May be provided as a filename or a raw string."
         ),
         callback=input_validator,
     ),
@@ -312,19 +349,13 @@ def flow_update(
     administered_by: List[str] = typer.Option(
         None, callback=principal_validator, hidden=True
     ),
-    assume_ownership: bool = typer.Option(
-        False,
-        "--assume-ownership",
-        help="Assume the ownership of the Flow. This can only be performed by user's "
-        "in the flow_administrators role.",
-    ),
     subscription_id: Optional[str] = typer.Option(
         None,
         help="The Globus Subscription which will be used to make this flow managed.",
     ),
     validate: bool = typer.Option(
         True,
-        help=("(EXPERIMENTAL) Perform rudimentary validation of the flow definition."),
+        help="(EXPERIMENTAL) Perform rudimentary validation of the flow definition.",
         case_sensitive=False,
         show_default=True,
     ),
@@ -335,6 +366,23 @@ def flow_update(
     """
     Update a Flow.
     """
+
+    flow_viewer = handle_aliases(
+        ("--flow-viewer", flow_viewer),
+        ("--viewer", viewer or None),
+        ("--visible-to", visible_to or None),
+    )
+    flow_starter = handle_aliases(
+        ("--flow-starter", flow_starter),
+        ("--starter", starter or None),
+        ("--runnable-by", runnable_by or None),
+    )
+    flow_administrator = handle_aliases(
+        ("--flow-administrator", flow_administrator),
+        ("--administrator", administrator or None),
+        ("--administered-by", administered_by or None),
+    )
+
     fc = create_flows_client(CLIENT_ID, flows_endpoint)
     flow_dict = process_input(definition)
     input_schema_dict = process_input(input_schema)
@@ -353,11 +401,10 @@ def flow_update(
         subscription_id,
         input_schema_dict,
         validate_definition=validate,
-        visible_to=visible_to,
-        runnable_by=runnable_by,
-        administered_by=administered_by,
     )
-    RequestRunner(method, format=output_format, verbose=verbose).run_and_render()
+    with warnings.catch_warnings():
+        warnings.simplefilter("ignore", category=DeprecationWarning)
+        RequestRunner(method, format=output_format, verbose=verbose).run_and_render()
 
 
 @app.command("lint")
@@ -365,8 +412,8 @@ def flow_lint(
     definition: str = typer.Option(
         ...,
         help=(
-            "JSON or YAML representation of the Flow to deploy. May be provided as a filename "
-            "or a raw string."
+            "JSON or YAML representation of the Flow to deploy. "
+            "May be provided as a filename or a raw string."
         ),
         prompt=True,
         callback=input_validator,
@@ -414,7 +461,9 @@ def flow_list(
         None,
         "--per-page",
         "-p",
-        help="The page size to return. Only valid when used without providing a marker.",
+        help=(
+            "The page size to return. Only valid when used without providing a marker."
+        ),
         min=1,
         max=50,
     ),
@@ -471,14 +520,13 @@ def flow_list(
         orderings=parsed_orderings,
         **role_param,
     )
-    with live_content:
-        RequestRunner(
-            method,
-            format=output_format,
-            verbose=verbose,
-            watch=watch,
-            fields=FlowListDisplayFields,
-        ).run_and_render()
+    RequestRunner(
+        method,
+        format=output_format,
+        verbose=verbose,
+        watch=watch,
+        fields=FlowListDisplayFields,
+    ).run_and_render()
 
 
 @app.command("display")
@@ -487,8 +535,9 @@ def flow_display(
     flow_definition: str = typer.Option(
         "",
         help=(
-            "JSON or YAML representation of the Flow to display. May be provided as a filename "
-            "or a raw string representing a JSON object or YAML definition."
+            "JSON or YAML representation of the Flow to display. "
+            "May be provided as a filename or a raw string "
+            "representing a JSON object or YAML definition."
         ),
         callback=input_validator,
         show_default=False,
@@ -677,31 +726,30 @@ def flow_run(
         manage_by=manage_by,
         tags=tags,
     )
-    with live_content:
-        result = RequestRunner(
-            method,
-            format=output_format,
-            verbose=verbose,
-            watch=watch,
-            fields=RunLogDisplayFields,
-            run_once=True,
-        ).run_and_render()
+    result = RequestRunner(
+        method,
+        format=output_format,
+        verbose=verbose,
+        watch=watch,
+        fields=RunLogDisplayFields,
+        run_once=True,
+    ).run_and_render()
 
-        if not result.is_api_error and watch:
-            action_id = result.data.get("action_id")
-            return flow_action_log(
-                action_id=action_id,
-                flow_id=flow_id,
-                flow_scope=flow_scope,
-                reverse=False,
-                limit=100,
-                marker=None,
-                per_page=50,
-                output_format=output_format,
-                watch=watch,
-                flows_endpoint=flows_endpoint,
-                verbose=verbose,
-            )
+    if not result.is_api_error and watch:
+        action_id = result.data.get("action_id")
+        return flow_action_log(
+            action_id=action_id,
+            flow_id=flow_id,
+            flow_scope=flow_scope,
+            reverse=False,
+            limit=100,
+            marker=None,
+            per_page=50,
+            output_format=output_format,
+            watch=watch,
+            flows_endpoint=flows_endpoint,
+            verbose=verbose,
+        )
 
 
 @app.command("action-list")
@@ -744,7 +792,9 @@ def flow_actions_list(
         None,
         "--per-page",
         "-p",
-        help="The page size to return. Only valid when used without providing a marker.",
+        help=(
+            "The page size to return. Only valid when used without providing a marker."
+        ),
         min=1,
         max=50,
     ),
@@ -794,7 +844,7 @@ def flow_actions_list(
     role_param = make_role_param(roles)
 
     fc = create_flows_client(CLIENT_ID, flows_endpoint)
-    callable = functools.partial(
+    method = functools.partial(
         fc.list_flow_actions,
         flow_id=flow_id,
         flow_scope=flow_scope,
@@ -805,14 +855,13 @@ def flow_actions_list(
         orderings=parsed_orderings,
         **role_param,
     )
-    with live_content:
-        RequestRunner(
-            callable,
-            format=output_format,
-            verbose=verbose,
-            watch=watch,
-            fields=RunListDisplayFields,
-        ).run_and_render()
+    RequestRunner(
+        method,
+        format=output_format,
+        verbose=verbose,
+        watch=watch,
+        fields=RunListDisplayFields,
+    ).run_and_render()
 
 
 @app.command("action-status")
@@ -844,10 +893,9 @@ def flow_action_status(
     """
     fc = create_flows_client(CLIENT_ID, flows_endpoint)
     method = functools.partial(fc.flow_action_status, flow_id, flow_scope, action_id)
-    with live_content:
-        RequestRunner(
-            method, format=output_format, verbose=verbose, watch=watch
-        ).run_and_render()
+    RequestRunner(
+        method, format=output_format, verbose=verbose, watch=watch
+    ).run_and_render()
 
 
 @app.command("action-resume")
@@ -882,10 +930,10 @@ def flow_action_resume(
     ),
     verbose: bool = verbosity_option,
 ):
-    """Resume a Flow in the INACTIVE state. If query-for-inactive-reason is set, and the
-    Flow Action is in an INACTIVE state due to requiring additional Consent, the required
-    Consent will be determined and you may be prompted to allow Consent using the Globus
-    Auth web interface.
+    """Resume a Flow in the INACTIVE state. If query-for-inactive-reason is set,
+    and the Flow Action is in an INACTIVE state due to requiring additional Consent,
+    the required Consent will be determined, and you may be prompted to allow Consent
+    using the Globus Auth web interface.
     """
     fc = create_flows_client(CLIENT_ID, flows_endpoint)
     if query_for_inactive_reason:
@@ -904,23 +952,20 @@ def flow_action_resume(
             if status == "INACTIVE" and code == "ConsentRequired":
                 flow_scope = details.get("required_scope")
 
-    with live_content:
-        result = RequestRunner(
-            functools.partial(fc.flow_action_resume, flow_id, flow_scope, action_id),
+    result = RequestRunner(
+        functools.partial(fc.flow_action_resume, flow_id, flow_scope, action_id),
+        format=output_format,
+        verbose=verbose,
+        watch=watch,
+        run_once=True,
+    ).run_and_render()
+    if not result.is_api_error and watch:
+        RequestRunner(
+            functools.partial(fc.flow_action_status, flow_id, flow_scope, action_id),
             format=output_format,
             verbose=verbose,
             watch=watch,
-            run_once=True,
         ).run_and_render()
-        if not result.is_api_error and watch:
-            RequestRunner(
-                functools.partial(
-                    fc.flow_action_status, flow_id, flow_scope, action_id
-                ),
-                format=output_format,
-                verbose=verbose,
-                watch=watch,
-            ).run_and_render()
 
 
 @app.command("action-release")
@@ -997,12 +1042,12 @@ def flow_action_log(
     reverse: bool = typer.Option(
         False,
         "--reverse",
-        help="Display logs starting from most recent and proceeding in reverse chronological order",
+        help="Display logs reverse chronological order (most recent first).",
         show_default=True,
     ),
     limit: int = typer.Option(
         None,
-        help="Set a maximum number of events from the log to return",
+        help="Set a maximum number of events from the log to return.",
         min=1,
         max=100,
     ),
@@ -1016,7 +1061,9 @@ def flow_action_log(
         None,
         "--per-page",
         "-p",
-        help="The page size to return. Only valid when used without providing a marker.",
+        help=(
+            "The page size to return. Only valid when used without providing a marker."
+        ),
         min=1,
         max=50,
     ),
@@ -1063,21 +1110,20 @@ def flow_action_log(
         fields=RunLogDisplayFields,
         detector=LogCompletionDetector,
     )
-    with live_content:
-        if output_format in {
-            RunLogOutputFormat.json,
-            RunLogOutputFormat.yaml,
-            RunLogOutputFormat.table,
-        }:
-            rr.run_and_render()
+    if output_format in {
+        RunLogOutputFormat.json,
+        RunLogOutputFormat.yaml,
+        RunLogOutputFormat.table,
+    }:
+        rr.run_and_render()
+    else:
+        result = rr.run()
+        if not result.is_api_error:
+            flow_def = fc.get_flow(flow_id)
+            output_format.visualize(result.result, flow_def)
         else:
-            result = rr.run()
-            if not result.is_api_error:
-                flow_def = fc.get_flow(flow_id)
-                output_format.visualize(result.result, flow_def)
-            else:
-                rr.format = RunLogOutputFormat.json
-                rr.render(result)
+            rr.format = RunLogOutputFormat.json
+            rr.render(result)
 
 
 @app.command("action-enumerate")
@@ -1109,7 +1155,9 @@ def flow_action_enumerate(
         None,
         "--per-page",
         "-p",
-        help="The page size to return. Only valid when used without providing a marker.",
+        help=(
+            "The page size to return. Only valid when used without providing a marker."
+        ),
         min=1,
         max=50,
     ),
@@ -1167,14 +1215,13 @@ def flow_action_enumerate(
         orderings=parsed_orderings,
         **role_param,
     )
-    with live_content:
-        RequestRunner(
-            method,
-            format=output_format,
-            verbose=verbose,
-            watch=watch,
-            fields=RunListDisplayFields,
-        ).run_and_render()
+    RequestRunner(
+        method,
+        format=output_format,
+        verbose=verbose,
+        watch=watch,
+        fields=RunListDisplayFields,
+    ).run_and_render()
 
 
 @app.command("action-update")
