@@ -10,7 +10,7 @@ import typer
 import yaml
 from globus_sdk import AuthClient, BaseClient, GlobusAPIError, GlobusHTTPResponse
 from requests import Response
-from rich.console import RenderableType, RenderGroup
+from rich.console import Group, RenderableType
 from rich.spinner import Spinner
 from rich.table import Table
 from rich.text import Text
@@ -19,7 +19,7 @@ from typing_extensions import Literal
 from .auth import get_authorizers_for_scopes
 from .constants import OutputFormat
 from .helpers import get_http_details
-from .rich_rendering import cli_content
+from .rich_rendering import cli_content, live_content
 
 _title_max_width = 25
 _uuid_min_width = 36
@@ -366,7 +366,7 @@ class Renderer:
                 s = self.spinner
                 renderables.append(s)
 
-            cli_content.rg = RenderGroup(*renderables)
+            cli_content.rg = Group(*renderables)
         else:
             if self.verbose:
                 typer.secho(self.details_as_str, fg=self.detail_style, err=True)
@@ -432,10 +432,14 @@ class RequestRunner:
         self.render(Result(globus_resp))
 
     def run_and_render(self) -> Result:
-        while True:
-            result = self.run()
-            self.render(result)
-            if not self.watch or self.run_once or result.completed:
-                break
-            sleep(2)
-        return result
+        result = self.run()
+
+        # It's assumed that no additional auth URL's will need to be written to STDOUT
+        # because of the successful call to `self.run()`, above.
+        with live_content:
+            while True:
+                self.render(result)
+                if not self.watch or self.run_once or result.completed:
+                    return result
+                sleep(2)
+                result = self.run()
